==> openshift-model-operatorhub-6.5.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface StepFluent<A extends StepFluent<A>> extends Fluent<A>{
  public String getResolving();
  public A withResolving(String resolving);
  public Boolean hasResolving();
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public StepResource getResource();
  public StepResource buildResource();
  public A withResource(StepResource resource);
  public Boolean hasResource();
  public StepFluent.ResourceNested<A> withNewResource();
  public StepFluent.ResourceNested<A> withNewResourceLike(StepResource item);
  public StepFluent.ResourceNested<A> editResource();
  public StepFluent.ResourceNested<A> editOrNewResource();
  public StepFluent.ResourceNested<A> editOrNewResourceLike(StepResource item);
  public String getStatus();
  public A withStatus(String status);
  public Boolean hasStatus();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceNested<N> extends Nested<N>,StepResourceFluent<StepFluent.ResourceNested<N>>{
    public N and();
    public N endResource();
    
  }
  
}

==> openshift-model-operatorhub-6.7.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface StepFluent<A extends StepFluent<A>> extends Fluent<A>{
  public String getResolving();
  public A withResolving(String resolving);
  public Boolean hasResolving();
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public StepResource getResource();
  public StepResource buildResource();
  public A withResource(StepResource resource);
  public Boolean hasResource();
  public StepFluent.ResourceNested<A> withNewResource();
  public StepFluent.ResourceNested<A> withNewResourceLike(StepResource item);
  public StepFluent.ResourceNested<A> editResource();
  public StepFluent.ResourceNested<A> editOrNewResource();
  public StepFluent.ResourceNested<A> editOrNewResourceLike(StepResource item);
  public String getStatus();
  public A withStatus(String status);
  public Boolean hasStatus();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceNested<N> extends Nested<N>,StepResourceFluent<StepFluent.ResourceNested<N>>{
    public N and();
    public N endResource();
    
  }
  
}
